@@ -2,6 +2,10 @@
 
 Lexical::Persistence - Persistent lexical variable values for arbitrary calls.
 
+=head1 VERSION
+
+version 1.023
+
 =head1 SYNOPSIS
 
 	#!/usr/bin/perl
@@ -35,7 +39,7 @@ nearly every aspect of Lexical::Persistence's behavior.
 
 Lexical::Persistence lets your code access persistent data through
 lexical variables.  This example prints "some value" because the value
-of $x perists in the $lp object between setter() and getter().
+of $x persists in the $lp object between setter() and getter().
 
 	use Lexical::Persistence;
 
@@ -617,7 +621,7 @@ http://search.cpan.org/dist/Lexical-Persistence/
 
 =head1 COPYRIGHT
 
-Lexical::Persistence in copyright 2006-2010 by Rocco Caputo.  All
+Lexical::Persistence in copyright 2006-2013 by Rocco Caputo.  All
 rights reserved.  Lexical::Persistence is free software.  It is
 released under the same terms as Perl itself.
 
